@@ -2,7 +2,7 @@
 
 // # nocov start
 
-bool has_openmp() {
+bool has_openmp(void) {
 #ifdef _OPENMP
   return true;
 #else
@@ -15,7 +15,7 @@ bool has_openmp() {
 #define OPENMP_THREADS_EXCEEDED 2
 
 
-SEXP Chas_openmp() {
+SEXP Chas_openmp(void) {
   return ScalarLogical(has_openmp());
 }
 
